@@ -524,7 +524,7 @@ gboolean
 as_content_rating_set_from_variant (AsContentRating *content_rating, GVariant *variant)
 {
 	GVariantIter inner_iter;
-	GVariantDict idict;
+	g_auto(GVariantDict) idict;
 	GVariant *tmp;
 	GVariant *v_child;
 	g_autoptr(GVariant) values_var = NULL;
