@@ -568,21 +568,22 @@ void
 as_pool_clear (AsPool *pool)
 {
 	AsPoolPrivate *priv = GET_PRIVATE (pool);
-	if (g_hash_table_size (priv->cpt_table) > 0) {
-		/* contents */
-		g_hash_table_unref (priv->cpt_table);
-		priv->cpt_table = g_hash_table_new_full (g_str_hash,
-							 g_str_equal,
-							 g_free,
-							 (GDestroyNotify) g_object_unref);
+	if (g_hash_table_size (priv->cpt_table) == 0)
+		return;
 
-		/* cid info set */
-		g_hash_table_unref (priv->known_cids);
-		priv->known_cids = g_hash_table_new_full (g_str_hash,
+	/* contents */
+	g_hash_table_unref (priv->cpt_table);
+	priv->cpt_table = g_hash_table_new_full (g_str_hash,
+						 g_str_equal,
+						 g_free,
+						 (GDestroyNotify) g_object_unref);
+
+	/* cid info set */
+	g_hash_table_unref (priv->known_cids);
+	priv->known_cids = g_hash_table_new_full (g_str_hash,
 						  g_str_equal,
 						  g_free,
 						  NULL);
-	}
 }
 
 /**
@@ -840,14 +841,14 @@ as_pool_load_metainfo_data (AsPool *pool)
 
 				mi_cid_desktop = g_strdup_printf ("%s.desktop", mi_cid);
 				/* check with .desktop suffix too */
-				if (!g_hash_table_contains (priv->known_cids, mi_cid_desktop)) {
+				if (g_hash_table_contains (priv->known_cids, mi_cid_desktop)) {
 					g_debug ("Skipped: %s (already known)", fname);
 					continue;
 				}
 			}
 
 			/* quickly check if we know the component already */
-			if (!g_hash_table_contains (priv->known_cids, mi_cid)) {
+			if (g_hash_table_contains (priv->known_cids, mi_cid)) {
 				g_debug ("Skipped: %s (already known)", fname);
 				continue;
 			}
@@ -926,7 +927,7 @@ as_pool_load_desktop_entries (AsPool *pool)
 		if (!as_flags_contains (priv->flags, AS_POOL_FLAG_READ_METAINFO)) {
 			g_autofree gchar *de_cid = g_path_get_basename (fname);
 
-			if (!g_hash_table_contains (priv->known_cids, de_cid)) {
+			if (g_hash_table_contains (priv->known_cids, de_cid)) {
 				g_debug ("Skipped: %s (already known)", fname);
 				continue;
 			}
@@ -934,7 +935,7 @@ as_pool_load_desktop_entries (AsPool *pool)
 			/* check without .desktop suffix too */
 			if (g_str_has_suffix (de_cid, ".desktop")) {
 				de_cid[strlen (de_cid) - 8] = '\0';
-				if (!g_hash_table_contains (priv->known_cids, de_cid)) {
+				if (g_hash_table_contains (priv->known_cids, de_cid)) {
 					g_debug ("Skipped: %s (already known)", fname);
 					continue;
 				}
@@ -1084,7 +1085,6 @@ as_pool_save_cache_file (AsPool *pool, const gchar *fname, GError **error)
 
 	cpts = as_pool_get_components (pool);
 	as_cache_file_save (fname, priv->locale, cpts, error);
-	g_ptr_array_unref (cpts);
 
 	return TRUE;
 }
@@ -1764,6 +1764,7 @@ as_cache_file_read (const gchar *fname, GError **error)
 				g_warning ("Ignored serialized component: %s", str);
 			}
 		}
+		g_variant_unref (cptv);
 	}
 
 	return cpts;
